@@ -1,5 +1,3 @@
-from __future__ import print_function
-from __future__ import division
 import sys
 import time
 
