@@ -1,18 +1,17 @@
 #ifndef PyMPI_CONFIG_MPICH_H
 #define PyMPI_CONFIG_MPICH_H
 
-#include "mpi-11.h"
-#include "mpi-12.h"
-#include "mpi-20.h"
-#include "mpi-22.h"
-#include "mpi-30.h"
-#include "mpi-31.h"
-#include "mpi-40.h"
+#include "mpiapi.h"
 
-/* These types are difficult to implement portably */
+/* These types may not be available */
+#ifndef MPI_REAL2
 #undef PyMPI_HAVE_MPI_REAL2
+#endif
+#ifndef MPI_MPI_COMPLEX4
 #undef PyMPI_HAVE_MPI_COMPLEX4
+#endif
 
+/* MPI I/O may not be available */
 #ifndef ROMIO_VERSION
 #include "mpi-io.h"
 #endif
