@@ -6,8 +6,8 @@
 def main():
     """Entry point for worker processes."""
     # pylint: disable=import-outside-toplevel
-    from . import _lib
-    _lib.server_main()
+    from . import _core
+    _core.server_main()
 
 
 if __name__ == '__main__':
